/****************************************************************************

 MESSAGE PASSING INTERFACE TEST CASE SUITE

 Copyright IBM Corp. 1995

 IBM Corp. hereby grants a non-exclusive license to use, copy, modify, and
 distribute this software for any purpose and without fee provided that the
 above copyright notice and the following paragraphs appear in all copies.

 IBM Corp. makes no representation that the test cases comprising this
 suite are correct or are an accurate representation of any standard.

 In no event shall IBM be liable to any party for direct, indirect, special
 incidental, or consequential damage arising out of the use of this software
 even if IBM Corp. has been advised of the possibility of such damage.

 IBM CORP. SPECIFICALLY DISCLAIMS ANY WARRANTIES INCLUDING, BUT NOT LIMITED
 TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS" BASIS AND IBM
 CORP. HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
 ENHANCEMENTS, OR MODIFICATIONS.

****************************************************************************

 These test cases reflect an interpretation of the MPI Standard.  They are
 are, in most cases, unit tests of specific MPI behaviors.  If a user of any
 test case from this set believes that the MPI Standard requires behavior
 different than that implied by the test case we would appreciate feedback.

 Comments may be sent to:
    Richard Treumann
    treumann@kgn.ibm.com

****************************************************************************

 MPI-Java version :
    Sung-Hoon Ko(shko@npac.syr.edu)
    Northeast Parallel Architectures Center at Syracuse University
    09/10/99

****************************************************************************
*/

import mpi.*;

class bsend_free {
  static public void main(String[] args) throws MPIException {
	
    final int ITER = 2;
    int i,me;
    int datain[] = new int[2000];
    int dataout[] = new int[2000];

    final int sizeofint = 4;
    byte buf[] = new byte[1000000*sizeofint+MPI.BSEND_OVERHEAD];

    Status status;
    Request request;
    Intracomm comm;
	

    MPI.Init(args);

    comm = MPI.COMM_WORLD;
    me = comm.Rank();

    MPI.Buffer_attach(buf);

    if(me == 0)  {
      for(i=0;i<ITER;i++)  {
	dataout[i] = i;
	request = comm.Ibsend(dataout,i,2000,MPI.INT,1,0);
	request.Free();
      }
      comm.Barrier();
    } else if(me == 1) {
      comm.Barrier();
      for(i=0;i<ITER;i++)  {
	status = comm.Recv(datain,0,2000,MPI.INT,0,0);
	if(datain[0] != i) 
	  System.out.println("ERROR  i="+i+" datain[0]="+datain[0]);
      }
    }
    if(me == 0)  System.out.println("Bsend_free TEST COMPLETE\n");
    MPI.Finalize();
  }
}

